==> haskell-wai-logger-2.4.0-152-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-logger
version:              2.4.0
visibility:           public
id:                   wai-logger-2.4.0-D0lovsK5AjG9QhHoHMMSeA
key:                  wai-logger-2.4.0-D0lovsK5AjG9QhHoHMMSeA
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI
category:             Web, Yesod
abi:                  31f290e63c330e1c805821ad5256449b
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-logger-2.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-logger-2.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.4.0-D0lovsK5AjG9QhHoHMMSeA
depends:
    base-4.15.1.0 byteorder-1.0.4-VarnEot4iOE5Yb3UNyEbu
    bytestring-0.10.12.1 fast-logger-3.1.1-CYdwPQIA01ZLKxwb9xRHHH
    http-types-0.12.3-L4VBkj9wBbpJhmiMCXrA05
    network-3.1.2.7-2x6X3kWddA03AmOITnySLy
    wai-3.2.3-4BBvzsOByYiKnH9wzG1k6K

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.4.0-299-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-logger
version:              2.4.0
visibility:           public
id:                   wai-logger-2.4.0-4MFhd5ohqyW5mpqweZYimp
key:                  wai-logger-2.4.0-4MFhd5ohqyW5mpqweZYimp
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI
category:             Web, Yesod
abi:                  e5e950377912602f83f2c8f89874a8c1
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-logger-2.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-logger-2.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-logger
hs-libraries:         HSwai-logger-2.4.0-4MFhd5ohqyW5mpqweZYimp
depends:
    base-4.15.1.0 byteorder-1.0.4-VarnEot4iOE5Yb3UNyEbu
    bytestring-0.10.12.1 fast-logger-3.1.2-51e0CUNDeLV5vXlixg34jU
    http-types-0.12.3-GFhxs6XVQ6bETbOR4vEFmW
    network-3.1.4.0-5PP4MrJJnZZJkybIlRRAPq
    wai-3.2.3-BDPWmqf0MooISXwouhUuyf

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
